@@ -1,3 +1,11 @@
+context("Fitting-Comp risk")
+set.seed(12345)
+
+# CRAN skip atlas check fix
+testthat::skip_if(grepl(pattern = "atlas", sessionInfo()$BLAS,
+                        ignore.case = TRUE))
+
+
 n <- 100
 alp <- 0.05
 lambda10 <- 1
